Absent

Struct Absent 

pub struct Absent;
Type for a value that must be absent.

This should be accompanied by serde attributes to indicate that:

  • the default value should be taken #[serde(default)]
  • it should never be serialized #[serde(skip_serializing)] (or #[serde(skip_serializing_if = "::json_serde::always")]; see always)

Deserialization always fails–the field must not be present–and serialization fails if it is ever invoked, hence the attributes above. With the schemars08 and schemars1 features, Absent’s JsonSchema implementation is the false schema, which no value satisfies.